# Media Control

> Convert your mobile to TV remote with python

Python application to access media controls on your PC / Laptop via your mobile.

## Usage 

Install the package and run the following command


```bash
media-control

                                 
#     █▀▀▀▀▀█ ▀ █   ▄▀▄ █▀▀▀▀▀█    
#     █ ███ █ ▄▀▄  ▄ █▀ █ ███ █    
#     █ ▀▀▀ █ ██▀ █▀ ▀  █ ▀▀▀ █    
#     ▀▀▀▀▀▀▀ █ █ ▀ ▀ ▀ ▀▀▀▀▀▀▀    
#     ▀  ▄█▄▀▀▀██▄▄ ▀█ █▀███ ▄▀    
#      ▀▀▄█ ▀▀  █ ▄ ▄███▄█▀▀█▄     
#     ██▄█▀ ▀▀██▀ ▄▄▀▄▀ ▀▄▄▀▀█▀    
#       █ █▄▀▀█▀██▀▀▀▀▀▄█▀ ██▄     
#     ▀▀▀▀▀▀▀▀▄█  ▀ ▀▀█▀▀▀█▀█      
#     █▀▀▀▀▀█ ▀▄▀ ▄  ▄█ ▀ ██▄▄▄    
#     █ ███ █ ▀▀ ▀▄▀█▄▀▀█▀▀▄███    
#     █ ▀▀▀ █  ███▀█▀ ▀▄▀▄▄▄▄█     
#     ▀▀▀▀▀▀▀ ▀▀▀ ▀▀        ▀▀▀    
                                 
                                 

#  * Debugger is active!
#  * Debugger PIN: 115-827-049
# This QR Code contains the URL for you to open the command panel in your browser
```

> For this package to work the device you are running this package and your browser should be on same network

## TODO

- [x] Display values for mouse acceleration, volume
- [x] Add Support for keyboard typing - display all the characters being typed including backspace and enter (like key stroke listeners) - https://www.toptal.com/developers/keycode
- [x] Create a python package using poetry and publish it to pypi
- [ ] Add Support for mouse scroll wheel - build a 3d mouse wheel scroll
- [ ] Polish the ui to make the UX more easy